@@ -21,7 +21,7 @@ Usage::
     list_lexicons_paginator: ListLexiconsPaginator = client.get_paginator("list_lexicons")
     list_speech_synthesis_tasks_paginator: ListSpeechSynthesisTasksPaginator = client.get_paginator("list_speech_synthesis_tasks")
 """
-from mypy_boto3_polly.client import PollyClient as Client, PollyClient
+from mypy_boto3_polly.client import PollyClient, PollyClient as Client
 from mypy_boto3_polly.paginator import (
     DescribeVoicesPaginator,
     ListLexiconsPaginator,
