@@ -17,10 +17,8 @@ Usage::
     list_speech_synthesis_tasks_paginator: ListSpeechSynthesisTasksPaginator = client.get_paginator("list_speech_synthesis_tasks")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from __future__ import annotations
-
 import sys
-from typing import Generator
+from typing import Iterator, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_polly.type_defs import (
     DescribeVoicesOutputTypeDef,
@@ -40,7 +38,7 @@ __all__ = ("DescribeVoicesPaginator", "ListLexiconsPaginator", "ListSpeechSynthe
 
 class DescribeVoicesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeVoices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.47/reference/services/polly.html#Polly.Paginator.DescribeVoices)
+    [Paginator.DescribeVoices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Paginator.DescribeVoices)
     """
 
     def paginate(
@@ -79,35 +77,35 @@ class DescribeVoicesPaginator(Boto3Paginator):
         ] = None,
         IncludeAdditionalLanguageCodes: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeVoicesOutputTypeDef, None, None]:
+    ) -> Iterator[DescribeVoicesOutputTypeDef]:
         """
-        [DescribeVoices.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.47/reference/services/polly.html#Polly.Paginator.DescribeVoices.paginate)
+        [DescribeVoices.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Paginator.DescribeVoices.paginate)
         """
 
 
 class ListLexiconsPaginator(Boto3Paginator):
     """
-    [Paginator.ListLexicons documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.47/reference/services/polly.html#Polly.Paginator.ListLexicons)
+    [Paginator.ListLexicons documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Paginator.ListLexicons)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListLexiconsOutputTypeDef, None, None]:
+    ) -> Iterator[ListLexiconsOutputTypeDef]:
         """
-        [ListLexicons.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.47/reference/services/polly.html#Polly.Paginator.ListLexicons.paginate)
+        [ListLexicons.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Paginator.ListLexicons.paginate)
         """
 
 
 class ListSpeechSynthesisTasksPaginator(Boto3Paginator):
     """
-    [Paginator.ListSpeechSynthesisTasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.47/reference/services/polly.html#Polly.Paginator.ListSpeechSynthesisTasks)
+    [Paginator.ListSpeechSynthesisTasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Paginator.ListSpeechSynthesisTasks)
     """
 
     def paginate(
         self,
         Status: Literal["scheduled", "inProgress", "completed", "failed"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListSpeechSynthesisTasksOutputTypeDef, None, None]:
+    ) -> Iterator[ListSpeechSynthesisTasksOutputTypeDef]:
         """
-        [ListSpeechSynthesisTasks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.47/reference/services/polly.html#Polly.Paginator.ListSpeechSynthesisTasks.paginate)
+        [ListSpeechSynthesisTasks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Paginator.ListSpeechSynthesisTasks.paginate)
         """
